@@ -285,7 +285,7 @@ void LogViewSearchWidget::showMessage(const QString &text, const QString &iconTe
     message->setText(text);
     message->show();
 
-    messageIcon->setPixmap(SmallIcon(iconText));
+    messageIcon->setPixmap(QIcon::fromTheme(iconText).pixmap(KIconLoader::SizeSmall));
     messageIcon->show();
 
     d->messageHidingTimer->start();
@@ -310,7 +310,7 @@ void LogViewSearchWidget::highlightAll()
             LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
 
             if (compareItem(item) == true) {
-                item->setBackgroundColor(item->columnCount() - 1, QColor(255, 255, 16 * 8 + 11));
+                item->setBackground(item->columnCount() - 1, QColor(255, 255, 16 * 8 + 11));
             }
 
             ++it;
